@@ -79,6 +79,7 @@ class Article(BaseObject):
         self.clinical_trials = []
         self.preprint = None
         self.related_objects = []
+        self.publication_history = []
         # group_title for use in posted_content Crossref deposits of preprints
         self.group_title = None
 
@@ -444,6 +445,15 @@ class Preprint(BaseObject):
         self.doi = doi
 
 
+class Event(BaseObject):
+    def __init__(self):
+        self.uri = None
+        self.doi = None
+        self.event_type = None
+        self.event_desc = None
+        self.date = None
+
+
 class ContentBlock:
     def __init__(self, block_type=None, content=None, attr=None):
         self.block_type = block_type
